function show_full_grid_data()

% read full grid data
fid = fopen('full_grid_data.dat');
TB = cell2mat(textscan(fid, '%f\t%f\n', 'CommentStyle', '#'));
fclose(fid);

% theta and alpha values corresponding to the data
alpha = linspace(0, 1, 11);
theta = 10:150;
[Alpha, Theta] = meshgrid(alpha, theta);

% reshape data vector to meshgrid-sized matrices
T = reshape(TB(:,1), size(Alpha));
B = reshape(TB(:,2), size(Alpha));

% create plot/evaluation grid
plot_alpha = linspace(0, 1, 101);
plot_theta = linspace(10, 150, 101);
[plot_Alpha, plot_Theta] = meshgrid(plot_alpha, plot_theta);

% evaluate full grid spline interpolant
% (note: in the paper, we do not use MATLAB to create the
% reference solution, but the "Geometric Tools Engine" in C++)
plot_T = interp2(Alpha, Theta, T, plot_Alpha, plot_Theta, 'spline');
plot_B = interp2(Alpha, Theta, B, plot_Alpha, plot_Theta, 'spline');

% plot T interpolant and full grid points
figure();
hold('on');
surf(plot_Theta', plot_Alpha', plot_T');
plot3(Theta', Alpha', T', 'k.', 'MarkerSize', 12);
xlabel('theta [degrees]');
ylabel('alpha_T');
zlabel('T [N]');
xlim([10 150]);
ylim([0 1]);
title('Full grid data/interpolant for T');
grid('on');
view(3);

% plot B interpolant and full grid points
figure();
hold('on');
surf(plot_Theta', plot_Alpha', plot_B');
plot3(Theta', Alpha', B', 'k.', 'MarkerSize', 12);
xlabel('theta [degrees]');
ylabel('alpha_B');
zlabel('B [N]');
xlim([10 150]);
ylim([0 1]);
title('Full grid data/interpolant for B');
grid('on');
view(3);

end
